@@ -42,7 +42,7 @@ int main(int argc, char **argv)
     about.addAuthor( ki18n("Alexander Rieder"), KLocalizedString(), "alexanderrieder@gmail.com" );
     about.addAuthor( ki18n("Aleix Pol Gonzalez"), ki18n("KAlgebra backend"), "aleixpol@kde.org" );
     about.addAuthor( ki18n("Miha Čančula"), ki18n("Octave backend"), "miha.cancula@gmail.com" );
-    about.addAuthor( ki18n("Filipe Saraiva"), ki18n("Scilab backend"), "filipe@kde.org", "http://filipesaraiva.info/" );
+    about.addAuthor( ki18n("Filipe Saraiva"), ki18n("Scilab and Python backends"), "filipe@kde.org", "http://filipesaraiva.info/" );
     about.addAuthor( ki18n("Martin Küttler"), ki18n("Interface"), "martin.kuettler@gmail.com" );
     KCmdLineArgs::init(argc, argv, &about);
 
